@@ -17,9 +17,21 @@ sub run {
 	my $conf = Dpkg::Control::HashCore->new;
 
 	if(!length($reponame)) {
+		FILE:
 		foreach my $file(glob("/etc/apt/sources.list.d/extrepo_*.sources")) {
 			next unless $file =~ /extrepo_(.*)\.sources/;
-			run($config, $mirror, $update_mode, $1);
+			my $repo = $1;
+			eval {
+				run($config, $mirror, $update_mode, $repo);
+			};
+			if($@) {
+				if ($@ =~ /Repository.*does not exist/) {
+					say "The repository $repo does not seem to exist (anymore?), so was not updated. Consider 'extrepo disable $repo'";
+					next FILE;
+				} else {
+					die $@;
+				}
+			}
 		}
 		return;
 	}
@@ -58,6 +70,7 @@ sub run {
 		if($mirror){
 			$conf->{'URIs'} = $mirror;
 		}
+		$conf->set_output_order(sort(keys %$conf));
 		$conf->save($aptfile);
 		print "Configuration for $reponame enabled.\n\nNote that configuration for this repository already existed; it was enabled, but not updated.\nFor updates, see the update command.\n";
 		return;
@@ -101,9 +114,30 @@ sub run {
 	if(!$enabled) {
 		die "None of the license inclusion policies in $reponame were enabled. Please edit /etc/extrepo/config.yaml and enable the required policies\n";
 	}
+
+	if(exists($repo->{source}{Architectures})) {
+		my $sysarch = qx/dpkg --print-architecture/; chomp $sysarch;
+		my $foreign_arch = qx/dpkg --print-foreign-architectures/;
+		my @targetarchs = ($sysarch, split(/\s+/, $foreign_arch));
+		my @havearchs = split /\s+/, $repo->{source}{Architectures};
+		my $found = 0;
+
+		ARCH:
+		foreach my $arch(@havearchs) {
+			if (grep { $arch eq $_ } @targetarchs) {
+				$found = 1;
+				last ARCH;
+			}
+		}
+		if(!$found) {
+			die "The repository $reponame does not support any of the architectures enabled on this system. Not proceeding with this repository.\n";
+		}
+	}
+	DEB822KEY:
 	foreach my $key(keys %{$repo->{source}}) {
 		my $value = $repo->{source}{$key};
 		$value =~ s/<COMPONENTS>/$components/g;
+		next DEB822KEY if(lc($key) eq "architectures");
 		$conf->{$key} = $value;
 	}
 
@@ -112,11 +146,14 @@ sub run {
 	if($update_mode && -f $aptfile) {
 		my $temp_conf = Dpkg::Control::HashCore->new;
 		$temp_conf->load($aptfile);
-		$conf->{Enabled} = $temp_conf->{Enabled} if exists($temp_conf->{Enabled});
-		print "Configuration for $reponame will be updated, but note the repository isn't enabled.\n" unless($conf->{Enabled});
+		if(exists($temp_conf->{Enabled})) {
+			$conf->{Enabled} = $temp_conf->{Enabled};
+			if($conf->{Enabled} eq "no") {
+				print "Configuration for $reponame will be updated, but note the repository isn't enabled.\n";
+			}
+		}
 	}
 
-
 	my $key_file = "/var/lib/extrepo/keys/$reponame.asc";
 	open my $key_fh, ">", "$key_file" or die "opening key file: $!";
 	print $key_fh $key_data;
@@ -128,6 +165,7 @@ sub run {
 		$conf->{'URIs'} = $mirror;
 	}
 
+	$conf->set_output_order(sort(keys %$conf));
 	$conf->save($aptfile) or die "writing apt config: $!\n";
 
 	if(!$update_mode && exists($repo->{"post-enable-commands"})) {
